Cheshire3 Object Model - Abstract Base Class
============================================

API
---

.. autoclass:: cheshire3.baseObjects.C3Object
   :members:


Implementations
---------------

There are no pre-configured out-of-the-box ready objects of this type.